/* eslint-disable max-len */

const general = { jenkinsfile: '' };
const node = { jenkinsfile: '', js: '' };

general.jenkinsfile = `pipeline {
  agent any

  environment {
      VERSION = VersionNumber([
          versionNumberString: 
              '\${BUILDS_ALL_TIME}',
          versionPrefix: '1.0.',
          worstResultForIncrement: 'SUCCESS'
      ])
      publish = 0
  }

  stages {
      stage('Setup') {
          steps {
              script {
                  currentBuild.displayName = env.VERSION
              }
              echo 'Setting up test environment'
              sh 'echo setup'
          }
      }
  }
  post {
      success {
          script {
              publish = sh script: "git log -1 | grep '\\\\[no publish\\\\]'", returnStatus: true
              if (publish != 0) {
                echo 'Deploying'
                sh 'echo deploy'
              } else {
                echo 'Build successful, Commit not marked for deploying'
                currentBuild.result = "UNSTABLE"
              }
          }
      }
  }
}
`;

node.jenkinsfile = `pipeline {
  agent any

  environment {
      VERSION = VersionNumber([
          versionNumberString:
              '\${BUILDS_ALL_TIME}',
          versionPrefix: '1.0.',
          worstResultForIncrement: 'SUCCESS'
      ])
  }

  stages {
      stage('Building') {
          steps {
              script {
                  currentBuild.displayName = env.VERSION
              }
              sh 'yarn ci \${VERSION}'
          }
      }
  }
}
`;

node.js = `/* eslint-disable no-process-exit */
/* eslint-disable no-console */
/* eslint-disable no-sync */
'use strict';

const fs = require ('fs');
const child_process = require ('child_process');

const pkg = JSON.parse (fs.readFileSync ('package.json', 'utf-8'));
[
  ,, pkg.version
] = process.argv;
fs.writeFileSync ('package.json', JSON.stringify (pkg, null, 2));

child_process.execSync ('yarn lint', { stdio: 'inherit' });
if (typeof pkg.scripts !== 'undefined' && typeof pkg.scripts.test === 'string')
  child_process.execSync ('yarn test', { stdio: 'inherit' });
if (
  typeof pkg.scripts !== 'undefined'
  && typeof pkg.scripts.compile === 'string'
)
  child_process.execSync ('yarn compile', { stdio: 'inherit' });

child_process.exec ('git log -1 | grep \\'\\\\[no publish\\\\]\\'')
  .addListener ('exit', (code) => {
    if (code === 0) {
      console.log ('build not marked for deployment');
      process.exit (1);
    }
    else { child_process.execSync ('yarn publish'); }
  });
`;

export { general, node };
